@@ -13,8 +13,9 @@ function(x,step,fleet.name,coleff,colcat,colmbw,unitseff,unitscat,unitsmbw,nmult
     if(any(colmbw > dim(x)[2])){stop("colmbw are the columns where the mean body weight is stored")}
     if(unitscat != "kg" && unitscat != "ton" && unitscat != "ind") {stop("unitscat must be a character (all fleets same unit) either kilograms ('kg'), tonnes ('ton') or numbers ('ind')")}
     if(unitsmbw != "kg" && unitsmbw != "g" && unitsmbw != "ind") {stop("unitsmbw must be a character (all fleets same unit) either grams ('g'), kilograms ('kg') or numbers ('ind')")}
-    if(length(unitscat) > 1 || length(unitsmbw) > 1) {stop("The catches and mean body weight of all fleets must be in the same units")}
+    if(length(unitscat) > 1 || length(unitsmbw) > 1) {stop("The catches and mean body weight of all fleets must be in the same units, thus this parameter must be of length 1")}
     if(nmult != "bill" && nmult != "mill" && nmult != "thou" && nmult != "hund" && nmult != "ind") {stop("nmult, the catch in numbers multiplier, must be 'bill' (billions), 'mill' (millions), 'thou' (thousands), 'hund' (hundreds), or 'ind' (single individuals)")}
+    if(length(nmult) > 1) {stop("Since the catches and mean body weight are in the same unit for both fleets, the nmult parameter must be of length 1")}
     if(paste(substr(season.dates[1],5,5),substr(season.dates[1],8,8),sep="") != "--" || paste(substr(season.dates[2],5,5),substr(season.dates[2],8,8),sep="") != "--")
       {stop("season.dates must be a length-2 character vector (start of season, end of season) with dates in the ISO 8601 international standard, i.e. yyyy-mm-dd")}
     cateff                         <- vector("list",2);
@@ -44,18 +45,20 @@ function(x,step,fleet.name,coleff,colcat,colmbw,unitseff,unitscat,unitsmbw,nmult
           as.numeric(format(as.Date(season.dates[1],"%Y-%m-%d"), "%d")) >  as.numeric(format(as.Date(season.dates[2],"%Y-%m-%d"), "%d")))
          {stop("Dates must be arranged in ascending order")}          
        start <- as.numeric(julian(as.Date(season.dates[1],"%Y-%m-%d"),origin=as.Date(paste(substr(season.dates[1],1,4),"-01-01",sep="")))) + 1;
-       (if(as.numeric(format(as.Date(season.dates[1],"%Y-%m-%d"), "%Y")) == as.numeric(format(as.Date(season.dates[2],"%Y-%m-%d"), "%Y"))) 
-         {end <-  as.numeric(julian(as.Date(season.dates[2],"%Y-%m-%d"),
-                                    origin=as.Date(paste(substr(season.dates[2],1,4),"-01-01",sep=""))) + 1)}
-       else 
-         {end <- (as.numeric(julian(as.Date(paste(substr(season.dates[1],1,4),"-12-31",sep="")),
-                                    origin=as.Date(paste(substr(season.dates[1],1,4),"-01-01",sep=""))))-start+2) + 
-                  as.numeric(julian(as.Date(season.dates[2],"%Y-%m-%d"),origin=as.Date(paste(substr(season.dates[2],1,4),"-01-01",sep="")))) + 1});
        for(i in 1:length(fleet.name))
          {
-         if(length(start:end) != dim(x)[1])
-           {stop("Check season.dates, you have a number of days that is not identical to the number of effort/catch/mean body weight observations \n Consider changing the dates")}
-         cateff$Data[[i]]              <- data.frame(time.step=start:end,x[,coleff[i]],x[,colcat[i]],x[,colmbw[i]]);
+          (if(as.numeric(format(as.Date(season.dates[1],"%Y-%m-%d"), "%Y")) == as.numeric(format(as.Date(season.dates[2],"%Y-%m-%d"), "%Y"))) 
+            {end <-  as.numeric(julian(as.Date(season.dates[2],"%Y-%m-%d"),
+                                       origin=as.Date(paste(substr(season.dates[2],1,4),"-01-01",sep=""))) + 1)
+             cateff$Data[[i]] <- data.frame(time.step=start:end,x[,coleff[i]],x[,colcat[i]],x[,colmbw[i]])}
+           else 
+            {end <- (as.numeric(julian(as.Date(paste(substr(season.dates[1],1,4),"-12-31",sep="")),
+                                       origin=as.Date(paste(substr(season.dates[1],1,4),"-01-01",sep=""))))-start+2) + 
+                     as.numeric(julian(as.Date(season.dates[2],"%Y-%m-%d"),origin=as.Date(paste(substr(season.dates[2],1,4),"-01-01",sep="")))) + 1
+             cateff$Data[[i]] <- data.frame(time.step=1:end,x[,coleff[i]],x[,colcat[i]],x[,colmbw[i]]);})
+#         if(length(start:(start+end)) != dim(x)[1])
+#           {stop("Check season.dates, you have a number of days that is not identical to the number of effort/catch/mean body weight observations \n Consider changing the dates")}
+#         cateff$Data[[i]]              <- data.frame(time.step=start:end,x[,coleff[i]],x[,colcat[i]],x[,colmbw[i]]);
          names(cateff$Data[[i]])[2:4]  <-c(paste("obseff.",unitseff[i],sep=""),
                                            paste("obscat.",unitscat,sep=""),
                                            paste("obsmbw.",unitsmbw,sep="")); 
@@ -169,7 +172,7 @@ function(x,step,fleet.name,coleff,colcat,colmbw,unitseff,unitscat,unitsmbw,nmult
                      as.numeric(format(as.Date(season.dates[2],"%Y-%m-%d"),"%W"))})
        for(i in 1:length(fleet.name))
          {
-         if(length(start:(start+end)) != length(x[,coleff[i]]))
+         if(length(start:end) != length(x[,coleff[i]]))
            {stop("Check season.dates, you have a number of weeks that is not identical to the number of effort/catch/mean body weight observations \n Consider changing the dates")}
          cateff$Data[[i]]              <- data.frame(time.step=start:end,x[,coleff[i]],x[,colcat[i]],x[,colmbw[i]]);
          names(cateff$Data[[i]])[2:4]  <-c(paste("obseff.",unitseff[i],sep=""),
